/****************************************************************************
 *   Copyright (C) 2004 by Arboretum Systems, Inc.                          *
 *   Technical administrator: Alain Mazy, hav@mazy.be                       *
 *   Lead program designer: Georges Jaroslaw, gjaro@arboretum.com           *
 *                                                                          *
 *   HyperEngine-AV is a video, audio and text editor that can be used to   *
 *   record, import, edit, process and arrange together video, sound and    *
 *   text. These are all achieved in the program's free-form document       *
 *   window, with no limitations to the number of tracks.                   *
 *   The purpose of this program is to provide to users at all levels of    *
 *   expertise a readily accessible tool enabling them to create movies,    *
 *   slide shows or presentations.                                          *
 *                                                                          *
 *   HyperEngine-AV itself is free software. However, plug-ins that can be  *
 *   used as add-ons to HyperEngine-AV may or may not be free software, at  *
 *   the discretion of each plug-in developer and as specified by these     *
 *   plug-ins' respective licenses.                                         *
 *   You can redistribute HyperEngine-AV itself and/or modify it under the  *
 *   terms of the GNU General Public License as published by the Free       *
 *   Software Foundation; either version 2 of the License, or (at your      *
 *   option) any later version.                                             *
 *                                                                          *
 *   HyperEngine-AV is distributed in the hope that it will be useful, but  *
 *   WITHOUT ANY WARRANTY; without even the implied warranty of             *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *   GNU General Public License for all applicable details.                 *
 *                                                                          *
 *   You should have received a copy of the GNU General Public License      *
 *   along with this program; if not, write to:                             *
 *   Free Software Foundation, Inc.,                                        *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.              *
 ****************************************************************************/
 
#define ZzProgressMngrLogic_h

#ifndef ZzProgressMngrLogic_h
#include "ZzProgressMngrLogic.h"
#endif //ZzProgressMngrLogic_h

#ifndef ZzTypes_h
#include "ZzTypes.h"
#endif //ZzTypes_h

#define KMaxProgressMngrHierarchDepth 128

class ZzProgressMngrLogic
{
	SInt32	fNbTasksForLevelInCurrentBranch[KMaxProgressMngrHierarchDepth];
	// debug
	SInt32	dbg_fCurrentSubTaskInLevel[KMaxProgressMngrHierarchDepth];

	double	fCurrentAbsOffset;
	double	fCurrentAbsScale;
	double	fWholeProgress;
	SInt32	fLevel;

private :
	double	ExtentForLevelInCurrentBranch(SInt32 level);

public :
	ZzProgressMngrLogic(int nbSubTasks = 0);
	void	SetNbSubTasks(SInt32 n);
	void	SetProgress(double p);
	double	GetWholeProgress();
	void	EnterSubTask();
	void	LeaveSubTask();
};

/*
	by default, a level has 0 subtasks
	ctor : sets current level to 0, offset to 0 and scale to 1.
	SetProgress() acts on the current level
	EnterSubTask() increments the level
	LeaveSubTask() increments the current absolute offset then decrements the level.
	SetNbTasks() sets the scale according to the extent of the current level and the number of sub tasks in this level
*/

